@@ -211,10 +211,10 @@ int play() {
        board_rect.h = 0;
        
        /* set window properties and create it */
-       SDL_WM_SetCaption("Mancala", "Mancala");
-       if (sprintf(icon_path, "%s/icon.png", RES_PATH) == 0)
-               printf("Problems assembling icon path.\n");
-       SDL_WM_SetIcon(LoadRes(icon_path), NULL);
+       // SDL_WM_SetCaption("Mancala", "Mancala");
+       // if (sprintf(icon_path, "%s/icon.png", RES_PATH) == 0)
+       //        printf("Problems assembling icon path.\n");
+       // SDL_WM_SetIcon(LoadRes(icon_path), NULL);
        if ((screen = SDL_SetVideoMode(tile->w*8, (tile->h*2) + Y_OFFSET, 16, SDL_FULLSCREEN))
                == NULL) {
                printf("Unable to set %dx%d video: %s", tile->w*8,
